@@ -3,6 +3,8 @@ from typing import *
 
 def normalize_axis_index(_0: int, _1: int, /):
     """
+    usage.dask: 1
+    usage.scipy: 18
     usage.xarray: 3
     """
     ...
