@@ -2,11 +2,6 @@ from typing import *
 
 
 class Timedelta:
-    def __init__(self, /, value: Literal["1", "1 hours"], unit: Literal["ms"]):
-        """
-        usage.dask: 2
-        """
-        ...
 
     # usage.dask: 1
     __module__: ClassVar[object]
@@ -14,6 +9,20 @@ class Timedelta:
     # usage.xarray: 1
     __name__: ClassVar[object]
 
+    @overload
+    def __add__(self, _0: pandas._libs.tslibs.timestamps.Timestamp, /):
+        """
+        usage.xarray: 2
+        """
+        ...
+
+    @overload
+    def __add__(self, _0: Union[numpy.ndarray, numpy.float64, numpy.int64], /):
+        """
+        usage.pandas: 17
+        """
+        ...
+
     def __add__(
         self,
         _0: Union[
@@ -30,6 +39,22 @@ class Timedelta:
         """
         ...
 
+    @overload
+    def __eq__(
+        self, _0: Union[numpy.ndarray, numpy.float64, numpy.int64, numpy.timedelta64], /
+    ):
+        """
+        usage.pandas: 58
+        """
+        ...
+
+    @overload
+    def __eq__(self, _0: pandas._libs.tslibs.timedeltas.Timedelta, /):
+        """
+        usage.dask: 4
+        """
+        ...
+
     def __eq__(
         self,
         _0: Union[
@@ -42,7 +67,7 @@ class Timedelta:
         /,
     ):
         """
-        usage.dask: 6
+        usage.dask: 4
         usage.pandas: 58
         """
         ...
@@ -65,9 +90,38 @@ class Timedelta:
         """
         ...
 
-    def __gt__(self, _0: Union[pandas.core.series.Series, numpy.ndarray], /):
+    @overload
+    def __gt__(self, _0: numpy.ndarray, /):
+        """
+        usage.pandas: 1
+        """
+        ...
+
+    @overload
+    def __gt__(self, _0: pandas._libs.tslibs.timedeltas.Timedelta, /):
+        """
+        usage.dask: 1
+        """
+        ...
+
+    @overload
+    def __gt__(self, _0: pandas.core.series.Series, /):
         """
         usage.dask: 2
+        """
+        ...
+
+    def __gt__(
+        self,
+        _0: Union[
+            pandas._libs.tslibs.timedeltas.Timedelta,
+            pandas.core.series.Series,
+            numpy.ndarray,
+        ],
+        /,
+    ):
+        """
+        usage.dask: 3
         usage.pandas: 1
         """
         ...
@@ -78,6 +132,12 @@ class Timedelta:
         """
         ...
 
+    def __lt__(self, _0: pandas._libs.tslibs.timedeltas.Timedelta, /):
+        """
+        usage.dask: 1
+        """
+        ...
+
     def __mod__(self, _0: numpy.timedelta64, /):
         """
         usage.pandas: 2
@@ -96,6 +156,30 @@ class Timedelta:
         """
         ...
 
+    @overload
+    def __radd__(
+        self,
+        _0: Union[
+            numpy.ndarray,
+            numpy.int64,
+            numpy.datetime64,
+            numpy.timedelta64,
+            numpy.float64,
+        ],
+        /,
+    ):
+        """
+        usage.pandas: 8
+        """
+        ...
+
+    @overload
+    def __radd__(self, _0: pandas._libs.tslibs.timestamps.Timestamp, /):
+        """
+        usage.dask: 1
+        """
+        ...
+
     def __radd__(self, _0: object, /):
         """
         usage.dask: 1
@@ -121,6 +205,30 @@ class Timedelta:
         """
         ...
 
+    @overload
+    def __rsub__(
+        self,
+        _0: Union[
+            numpy.ndarray,
+            numpy.float64,
+            numpy.timedelta64,
+            numpy.int64,
+            numpy.datetime64,
+        ],
+        /,
+    ):
+        """
+        usage.pandas: 10
+        """
+        ...
+
+    @overload
+    def __rsub__(self, _0: pandas._libs.tslibs.timestamps.Timestamp, /):
+        """
+        usage.dask: 3
+        """
+        ...
+
     def __rsub__(self, _0: object, /):
         """
         usage.dask: 3
