@@ -2,12 +2,6 @@ from typing import *
 
 
 class IndexOpsMixin:
-    def factorize(self, /):
-        """
-        usage.xarray: 4
-        """
-        ...
-
     def max(self, /):
         """
         usage.dask: 18
@@ -32,15 +26,8 @@ class IndexOpsMixin:
         """
         ...
 
-    def to_numpy(self, /):
-        """
-        usage.xarray: 3
-        """
-        ...
-
     def tolist(self, /):
         """
         usage.dask: 14
-        usage.sklearn: 1
         """
         ...
