@@ -14,7 +14,7 @@ CategoricalDtype: object
 # usage.xarray: 6
 CategoricalIndex: object
 
-# usage.dask: 310
+# usage.dask: 309
 # usage.sklearn: 54
 # usage.xarray: 10
 DataFrame: object
@@ -82,7 +82,7 @@ RangeIndex: object
 # usage.xarray: 20
 Series: object
 
-# usage.dask: 5
+# usage.dask: 4
 # usage.xarray: 1
 Timedelta: object
 
@@ -90,7 +90,7 @@ Timedelta: object
 # usage.xarray: 9
 TimedeltaIndex: object
 
-# usage.dask: 16
+# usage.dask: 12
 # usage.xarray: 2
 Timestamp: object
 
@@ -109,35 +109,21 @@ UInt64Index: object
 # usage.dask: 1
 UInt8Dtype: object
 
-# usage.dask: 1
 # usage.sklearn: 3
 # usage.xarray: 6
 __version__: object
 
-# usage.dask: 1
-_libs: object
-
-# usage.dask: 20
-# usage.sklearn: 10
-api: object
-
 # usage.dask: 15
 array: object
 
-# usage.sklearn: 3
-arrays: object
-
 # usage.dask: 31
 # usage.sklearn: 2
 concat: object
 
-# usage.dask: 12
-core: object
-
 # usage.xarray: 1
 cut: object
 
-# usage.dask: 51
+# usage.dask: 50
 # usage.xarray: 106
 date_range: object
 
@@ -182,10 +168,6 @@ read_csv: object
 # usage.dask: 3
 read_json: object
 
-# usage.dask: 2
-# usage.xarray: 5
-testing: object
-
 # usage.dask: 3
 # usage.xarray: 1
 timedelta_range: object
@@ -200,9 +182,3 @@ to_numeric: object
 # usage.dask: 3
 # usage.xarray: 2
 to_timedelta: object
-
-# usage.dask: 5
-tseries: object
-
-# usage.dask: 2
-util: object
